@@ -4,6 +4,7 @@ __all__ = [
     "completion",
     "InstructorMode",
     "BaseModel",
+    "PredefinedModel",
     "Field",
 
     # llm
@@ -33,6 +34,7 @@ from .main import (
     Completions,
     completion,
     InstructorMode,
+    PredefinedModel,
     BaseModel,
     Field
 )
